#[non_exhaustive]pub enum ValidationOption {
FailFast,
Filter(Arc<dyn Filter>),
NowFn(Arc<dyn Fn() -> Timestamp + Send + Sync>),
}Expand description
Options for configuring a single Validator::validate_with call.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
FailFast
Stop validation on the first violation instead of collecting all.
Filter(Arc<dyn Filter>)
Override the filter for this validation call.
NowFn(Arc<dyn Fn() -> Timestamp + Send + Sync>)
Override the function used to populate now in timestamp-based rules/CEL.