pub fn is_email(s: &str) -> bool
Returns true if s is a valid email address.
true
s
Checks for a non-empty local part and domain separated by @, with the domain being a valid hostname or IP address literal.
@